"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _AsyncPickerHeader = _interopRequireDefault(require("./AsyncPickerHeader"));

var _AsyncPickerConfigsContext = require("./utils/AsyncPickerConfigsContext");

var _helpers = require("./utils/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const AsyncPickerModule = props => {
  const {
    renderItem,
    data,
    value,
    searchableStringExtractor,
    onChange,
    keyExtractor,
    limit = 0,
    onClose,
    onOpen,
    onSearch,
    closeOnSelect,
    isLoading,
    noResultComponent,
    ListEmptyComponent,
    ...otherProps
  } = props;
  const {
    configs
  } = (0, _AsyncPickerConfigsContext.useAsyncPickerConfigs)();
  const [inputValue, setInputValue] = (0, _react.useState)('');
  const [searchResult, setSearchResult] = (0, _react.useState)([]);

  const onOptionPress = option => {
    if (limit !== 1) {
      if (value.find(el => keyExtractor(el) === keyExtractor(option))) {
        onChange(value.filter(el => keyExtractor(el) !== keyExtractor(option)));
        return;
      }
    }

    const selectedItems = limit === 1 ? [option] : [...value, option];

    if (limit && limit > 1 && selectedItems.length > limit) {
      return;
    }

    onChange(selectedItems);

    if (closeOnSelect && onClose) {
      onClose();
    }
  };

  const getOptions = (0, _react.useCallback)(() => {
    if (searchableStringExtractor && inputValue) {
      return searchResult;
    }

    return data;
  }, [searchableStringExtractor, searchResult, data, !!inputValue]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flex: 1,
      backgroundColor: configs.colors.backgroundColor
    }
  }, /*#__PURE__*/_react.default.createElement(_AsyncPickerHeader.default, {
    onSave: onClose,
    title: "Search"
  }), (searchableStringExtractor || onSearch) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      margin: 16,
      justifyContent: 'center'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    value: inputValue,
    onChangeText: el => {
      setInputValue(el);

      if (onSearch) {
        onSearch(el);
      }

      if (searchableStringExtractor) {
        const res = data === null || data === void 0 ? void 0 : data.filter(item => (0, _helpers.isTextIncludedInString)(el, searchableStringExtractor(item)));
        setSearchResult(res || []);
      }
    },
    placeholder: "Search ...",
    style: configs.searchInputStyle,
    clearButtonMode: "while-editing"
  }), isLoading && /*#__PURE__*/_react.default.createElement(_reactNative.ActivityIndicator, {
    style: {
      position: 'absolute',
      right: 32
    }
  })), /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, _extends({
    data: getOptions() || [],
    keyExtractor: keyExtractor,
    renderItem: _ref => {
      let {
        item,
        index,
        separators
      } = _ref;
      const isActive = value.some(el => keyExtractor(el) === keyExtractor(item));
      const isDisabled = !isActive && !!limit && limit > 1 && value.length === limit;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderItem({
        item,
        index,
        separators,
        isActive,
        isDisabled,
        onItemPress: onOptionPress
      }));
    },
    ListEmptyComponent: isLoading ? undefined : !!inputValue ? noResultComponent ? noResultComponent(inputValue) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: {
        textAlign: 'center'
      }
    }, "No results")) : ListEmptyComponent
  }, otherProps)));
};

var _default = AsyncPickerModule;
exports.default = _default;
//# sourceMappingURL=AsyncPickerModule.js.map