function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useCallback, useState } from 'react';
import { ActivityIndicator, FlatList, Text, TextInput, View } from 'react-native';
import AsyncPickerHeader from './AsyncPickerHeader';
import { useAsyncPickerConfigs } from './utils/AsyncPickerConfigsContext';
import { isTextIncludedInString } from './utils/helpers';

const AsyncPickerModule = props => {
  const {
    renderItem,
    data,
    value,
    searchableStringExtractor,
    onChange,
    keyExtractor,
    limit = 0,
    onClose,
    onOpen,
    onSearch,
    closeOnSelect,
    isLoading,
    noResultComponent,
    ListEmptyComponent,
    ...otherProps
  } = props;
  const {
    configs
  } = useAsyncPickerConfigs();
  const [inputValue, setInputValue] = useState('');
  const [searchResult, setSearchResult] = useState([]);

  const onOptionPress = option => {
    if (limit !== 1) {
      if (value.find(el => keyExtractor(el) === keyExtractor(option))) {
        onChange(value.filter(el => keyExtractor(el) !== keyExtractor(option)));
        return;
      }
    }

    const selectedItems = limit === 1 ? [option] : [...value, option];

    if (limit && limit > 1 && selectedItems.length > limit) {
      return;
    }

    onChange(selectedItems);

    if (closeOnSelect && onClose) {
      onClose();
    }
  };

  const getOptions = useCallback(() => {
    if (searchableStringExtractor && inputValue) {
      return searchResult;
    }

    return data;
  }, [searchableStringExtractor, searchResult, data, !!inputValue]);
  return /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      backgroundColor: configs.colors.backgroundColor
    }
  }, /*#__PURE__*/React.createElement(AsyncPickerHeader, {
    onSave: onClose,
    title: "Search"
  }), (searchableStringExtractor || onSearch) && /*#__PURE__*/React.createElement(View, {
    style: {
      margin: 16,
      justifyContent: 'center'
    }
  }, /*#__PURE__*/React.createElement(TextInput, {
    value: inputValue,
    onChangeText: el => {
      setInputValue(el);

      if (onSearch) {
        onSearch(el);
      }

      if (searchableStringExtractor) {
        const res = data === null || data === void 0 ? void 0 : data.filter(item => isTextIncludedInString(el, searchableStringExtractor(item)));
        setSearchResult(res || []);
      }
    },
    placeholder: "Search ...",
    style: configs.searchInputStyle,
    clearButtonMode: "while-editing"
  }), isLoading && /*#__PURE__*/React.createElement(ActivityIndicator, {
    style: {
      position: 'absolute',
      right: 32
    }
  })), /*#__PURE__*/React.createElement(FlatList, _extends({
    data: getOptions() || [],
    keyExtractor: keyExtractor,
    renderItem: _ref => {
      let {
        item,
        index,
        separators
      } = _ref;
      const isActive = value.some(el => keyExtractor(el) === keyExtractor(item));
      const isDisabled = !isActive && !!limit && limit > 1 && value.length === limit;
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderItem({
        item,
        index,
        separators,
        isActive,
        isDisabled,
        onItemPress: onOptionPress
      }));
    },
    ListEmptyComponent: isLoading ? undefined : !!inputValue ? noResultComponent ? noResultComponent(inputValue) : /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Text, {
      style: {
        textAlign: 'center'
      }
    }, "No results")) : ListEmptyComponent
  }, otherProps)));
};

export default AsyncPickerModule;
//# sourceMappingURL=AsyncPickerModule.js.map