import React from 'react';
import { Text, TouchableOpacity, View, ViewProps } from 'react-native';
import { useAsyncPickerConfigs } from './utils/AsyncPickerConfigsContext';

interface AsyncPickerChipsProps<T> extends ViewProps {
  item: T;
  label: string;
  onRemove?: (item: T) => void;
}

const AsyncPickerChips = <T,>({
  item,
  label,
  onRemove,
  ...props
}: AsyncPickerChipsProps<T>) => {
  const { configs } = useAsyncPickerConfigs();

  return (
    <View style={configs.chipsItemContainerStyle} {...props}>
      <Text style={[configs.chipsItemTextStyle]}>{label}</Text>

      {onRemove && (
        <TouchableOpacity
          activeOpacity={0.7}
          onPress={() => {
            onRemove(item);
          }}
          style={configs.chipsItemCloseButtonStyle}
        >
          <Text style={{ fontSize: 8 }}>✕</Text>
        </TouchableOpacity>
      )}
    </View>
  );
};

export default AsyncPickerChips;
