import React from 'react';
import { Text, TouchableOpacity, View, ViewProps } from 'react-native';
import { useAsyncPickerConfigs } from './utils/AsyncPickerConfigsContext';

interface AsyncPickerHeaderProps extends ViewProps {
  onCancel?: () => void;
  title?: string;
  onSave?: () => void;
}

const AsyncPickerHeader: React.FC<AsyncPickerHeaderProps> = ({
  onCancel,
  onSave,
  title,
  ...props
}) => {
  const { configs } = useAsyncPickerConfigs();

  return (
    <View {...props}>
      <View style={configs.headerContainerStyle}>
        <View style={{ flex: 1 }}>
          {onCancel && (
            <TouchableOpacity
              onPress={() => {
                onCancel();
              }}
            >
              <Text style={configs.headerTextStyle}>Cancel</Text>
            </TouchableOpacity>
          )}
        </View>
        <View style={{ flex: 1 }}>
          {title && (
            <Text numberOfLines={1} style={configs.headerTitleStyle}>
              {title}
            </Text>
          )}
        </View>
        <View
          style={{
            flex: 1,
            flexDirection: 'row',
            justifyContent: 'flex-end',
          }}
        >
          {onSave && (
            <TouchableOpacity
              onPress={() => {
                onSave();
              }}
            >
              <Text style={configs.headerTextStyle}>Done</Text>
            </TouchableOpacity>
          )}
        </View>
      </View>
    </View>
  );
};

export default AsyncPickerHeader;
