import React from 'react';
import { Text, TouchableOpacity, TouchableOpacityProps } from 'react-native';
import AsyncPickerCheckBox from './AsyncPickerCheckBox';
import { useAsyncPickerConfigs } from './utils/AsyncPickerConfigsContext';

interface AsyncPickerItemProps extends TouchableOpacityProps {
  value: string;
  label?: string;
  isActive?: boolean;
  as?: 'checkbox' | 'radio';
  renderIcon?: (isActive: boolean) => React.ReactNode;
}

const AsyncPickerItem = React.memo<AsyncPickerItemProps>(
  ({ label, value, isActive, renderIcon, as = 'checkbox', ...props }) => {
    const { configs } = useAsyncPickerConfigs();

    return (
      <TouchableOpacity
        style={[
          configs.pickerItemContainerStyle,
          props.disabled && configs.pickerItemDisabledStyle,
        ]}
        {...props}
      >
        <>
          {renderIcon ? (
            renderIcon(isActive ? true : false)
          ) : (
            <AsyncPickerCheckBox
              isActive={isActive}
              color={configs.colors.checkboxOff}
              activeColor={configs.colors.checkboxOn}
              size={configs.sizes.checkboxSize}
              borderRadius={
                as === 'radio'
                  ? configs.sizes.checkboxSize / 2
                  : configs.sizes.checkboxBorderRadius
              }
            />
          )}
        </>

        <Text numberOfLines={1} style={configs.pickerItemTextStyle}>
          {label || value}
        </Text>
      </TouchableOpacity>
    );
  }
);

export default AsyncPickerItem;
